const Service = require("../models/ServiceModel");

// Add a new service
exports.addService = async (req, res) => {
  try {
    const service = await Service.create(req.body);
    res.status(201).json(service);
  } catch (error) {
    res.status(400).json({ message: error.message });
  }
};

// Get all services
exports.getAllServices = async (req, res) => {
  try {
    const services = await Service.findAll();
    res.json(services);
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
};


// Get services by listing type
exports.getServicesByType = async (req, res) => {
  try {
    const { level } = req.params; // Extract the type from the route parameter
    const services = await Service.findAll({
      where: { level:level }, // Filter by listingType
    });

    if (services.length === 0) {
      return res.status(404).json({ message: "No services found for the specified type" });
    }

    res.json(services);
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
};


// Get a single service by ID
exports.getServiceById = async (req, res) => {
  try {
    const { id } = req.params;
    const service = await Service.findByPk(id);

    if (!service) {
      return res.status(404).json({ message: "Service not found" });
    }

    res.json(service);
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
};

// Update a service
exports.updateService = async (req, res) => {
  try {
    const { id } = req.params;
    const service = await Service.findByPk(id);

    if (!service) {
      return res.status(404).json({ message: "Service not found" });
    }

    const updatedService = await service.update(req.body);
    res.json({ message: "Service updated successfully", updatedService });
  } catch (error) {
    res.status(400).json({ message: error.message });
  }
};

// Delete a service
exports.deleteService = async (req, res) => {
  try {
    const { id } = req.params;
    const service = await Service.findByPk(id);

    if (!service) {
      return res.status(404).json({ message: "Service not found" });
    }

    await service.destroy();
    res.json({ message: "Service deleted successfully" });
  } catch (error) {
    res.status(500).json({ message: error.message });
  }
};

// Search services by keyword
exports.searchServices = async (req, res) => {
  try {
    const { query } = req.query; // Extract the search query from request query parameters
    const services = await Service.findAll({
      where: {
        name: {
          [Op.like]: `%${query}%`, // Partial match for the service name
        },
      },
    });

    if (services.length === 0) {
      return res.status(404).json({ message: "No services match your search query" });
    }

    res.json(services);
  } catch (error) {
    res.status(500).json({ message: error.message });
  }

}