const express = require("express");
const path = require("path");
const sequelize = require("./config/db");
const bodyParser = require("body-parser");
require("dotenv").config();

// Import Models
const User = require("./models/Userm");
const Service = require("./models/ServiceModel");
const Booking = require("./models/Booking");

// Base route prefix
// const BASE_PATH = "/pragma_api";

const app = express();
app.use(bodyParser.json());

app.use("/public", express.static(path.join(__dirname, "public")));

// Test database connection and sync models
sequelize.authenticate()
  .then(() => console.log("Database connected..."))
  .catch(err => console.log("Error: " + err));

sequelize.sync({ force: false }).then(() => {
  console.log("Tables synced successfully.");
});



const userRoutes = require("./routes/userRoutes");
app.use("/api/users", userRoutes);
const serviceRoutes = require("./routes/serviceRoutes");
app.use("/api/services", serviceRoutes);
const categoryRoutes = require("./routes/categoryRoutes");
app.use("/api/categories", categoryRoutes);



// // Routes with BASE_PATH
// const userRoutes = require("./routes/userRoutes");
// app.use(`${BASE_PATH}/api/users`, userRoutes);

// const serviceRoutes = require("./routes/serviceRoutes");
// app.use(`${BASE_PATH}/api/services`, serviceRoutes);



// Start server
const PORT = process.env.PORT || 5000;
app.listen(PORT, () => console.log(`Server running on port ${PORT}`));
